<?php
session_start();

// Ensure the user is logged in and is a manager
if (!isset($_SESSION['staff_id']) || $_SESSION['user_role'] !== 'manager') {
    die("Access denied.");
}

$requestID = isset($_GET['requestID']) ? $_GET['requestID'] : null;

if (!$requestID) {
    die("Invalid request.");
}

// Database connection credentials
$db_host = "localhost";
$db_name = "PROJ01";
$db_user = "proj01";
$db_pass = "csc4341";

try {
    // Establish PDO connection
    $db_con = new PDO("mysql:host={$db_host};dbname={$db_name}", $db_user, $db_pass);
    $db_con->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Fetch request details
    $stmt = $db_con->prepare("
        SELECT
            r.RequestID,
            r.RequestType,
            r.Status,
            r.Comments,
            CONCAT(s.FirstName, ' ', s.LastName) AS StudentName,
            s.Email AS StudentEmail
        FROM Request r
        INNER JOIN Student s ON r.StudentID = s.StudentID
        WHERE r.RequestID = :requestID
    ");
    $stmt->execute([':requestID' => $requestID]);
    $request = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$request) {
        die("Request not found.");
    }

    // Fetch uploaded documents
    $docStmt = $db_con->prepare("
        SELECT DocumentID, DocumentName, UploadDate
        FROM Document
        WHERE RequestID = :requestID
    ");
    $docStmt->execute([':requestID' => $requestID]);
    $documents = $docStmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("Database error: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>View Submission</title>
    <link rel="stylesheet" href="styles.css">
</head>
<body>
    <header>
        <nav>
            <div class="logo">
                <h1>Manager Dashboard</h1>
            </div>
            <ul class="nav-links">
                <li><a href="manager_page.php">Back to Dashboard</a></li>
                <li><a href="home.html">Logout</a></li>
            </ul>
        </nav>
    </header>

    <main>
        <section>
            <h2>Submission Details</h2>
            <p><strong>Student Name:</strong> <?php echo $request['StudentName']; ?></p>
            <p><strong>Request Type:</strong> <?php echo $request['RequestType']; ?></p>
            <p><strong>Status:</strong> <?php echo $request['Status']; ?></p>
            <p><strong>Comments:</strong> <?php echo $request['Comments']; ?></p>

            <h3>Uploaded Documents</h3>
            <?php if (!empty($documents)): ?>
                <ul>
                    <?php foreach ($documents as $doc): ?>
                        <li>
                            <a href="download.php?document_id=<?php echo urlencode($doc['DocumentID']); ?>">
                                <?php echo htmlspecialchars($doc['DocumentName']); ?>
                            </a> (Uploaded on: <?php echo htmlspecialchars($doc['UploadDate']); ?>)
                        </li>
                    <?php endforeach; ?>
                </ul>
            <?php else: ?>
                <p>No documents uploaded for this request.</p>
            <?php endif; ?>

            <h3>Update Status</h3>
            <form method="POST">
                <label for="status">Status:</label>
                <select id="status" name="status" required>
                    <option value="processing" <?php echo $request['Status'] === 'processing' ? 'selected' : ''; ?>>Processing</option>
                    <option value="completed" <?php echo $request['Status'] === 'completed' ? 'selected' : ''; ?>>Completed</option>
                </select>
                <button type="submit">Update</button>
            </form>
        </section>
    </main>

    <footer>
        <p>&copy; 2024 Document Submission Management System</p>
    </footer>
</body>
</html>




